*                          MICRON HSPICE MODEL
*
* Disclaimer:  This software code and all associated documentation, comments
*              or other information (collectively "Software") is provided 
*              "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC. 
*              ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*              INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*              RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*              FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*              SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*              THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*              MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*              RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*              ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*              OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*              EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*              LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*              SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*              OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*              ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*              EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*              Because some jurisdictions prohibit the exclusion or limitation
*              of liability for consequential or incidental damages, the above
*              limitation may not apply to you.
* 
*              Copyright 2004 Micron Technology, Inc. All rights reserved.
*
***************************** 2Mbx32 SDRAM *************************************
************************* HSPICE setup for CLK ********************************

************************************************************
****             ___                                       *
****            /   |------PAD----\/\/\/--@@@@-----IN_PKG  *
**** RCVR_OUT--{    |             R_pkg  L_pkg |           *
****            \___|------RCVR_EN            === C_pkg    *
****                                           |           *
****                                          GND          *
****                                                       *
************************************************************

**** This netlist is for the x32 64Mb SDRAM ***********************************
**** The input signal is IN_PKG (input signal). 
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values, 
**** netlist elements r_pkg, l_pkg, and c_pkg have been attached to the PAD node. 

**** The MOS models selected for this netlist are SS, TT, FF.
****   The different possible modes are 
****     TT-- Typical N, Typical P
****     SS-- Slow N, Slow P
****     FF-- Fast N, Fast P
**** To run this simulation, the files "y14w_model.cnr" and "y14w_clkbuff.inc" are 
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 40C, Slow 85C, Fast 0C   

.OPTIONS ACCT OPTS NOPAGE POST
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns 25.0ns

.TEMP 85
.LIB "y14w_model.cnr" SS

**** Input Signal and Power Supply Setup
**** Note: vccr and vbb are regulated internal voltages
**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc_typ    = 3.300V
.PARAM  vcc_min    = 3.000V
.PARAM  vcc_max    = 3.600V

.PARAM  vccr_typ   = 2.468V
.PARAM  vccr_min   = 2.441V
.PARAM  vccr_max   = 2.501V

.PARAM  vbb_typ    = -0.774V
.PARAM  vbb_min    = -0.862V
.PARAM  vbb_max    = -0.755V 

.PARAM  gnd       = 0.0V
.PARAM  vss       = 0.0V
********************************************************************************
.PARAM  vcc       = vcc_min
.PARAM  vccr      = vccr_min
.PARAM  vbb       = vbb_min
******************************************************************************** 
Vvss    vss    0  DC = vss
Vvcc    vcc    0  DC = vcc
Vvccr   vccr   0  DC = vccr
Vvbb    vbb    0  DC = vbb 

Ven   rcvr_en  0  DC = vccr
** Enable signal is active high (vccr)

***Input Stimulus Parameters
.param freq=166.0e6
.param per='1/freq'
.param tr=1.0n
.param tf=1.0n
.param pw='0.5*per-tr'
.param signal_delay=1.0ns

****INPUT SIGNAL
Vin   in_pkg  0  pulse 0 vcc signal_delay tr tf pw per

** top level circuit
xi0 pad rcvr_en rcvr_out gnd vbb vccr vcc y14w_clkbuff

* Refer to the Ibis model for specific package parasitic values
r_pkg pad net1 r=91.7e-3 
l_pkg net1 in_pkg l=4.64e-9
c_pkg in_pkg gnd c=0.91e-12

.alter typ
.PARAM  vcc         = vcc_typ
.PARAM  vccr        = vccr_typ
.PARAM  vbb         = vbb_typ
.temp 40
.lib "y14w_model.cnr" TT

.alter fast
.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max
.PARAM  vbb         = vbb_max
.temp 0
.lib "y14w_model.cnr" FF

.END
